@@ -174,9 +174,13 @@ def _merge_funcs_and_named_funcs(funcs, named_funcs):
     )
 
 
-def uniquize_funcs_names(named_funcs_obtained_from_funcs):
+def uniquize_funcs_names(named_funcs_obtained_from_funcs, suffic_counter_start=2):
+    """
+    Check and make sure that the functions names are all different. This is achieved by adding a suffix to
+    the duplicate names
+    """
     all_func_names = []
-    prefix_counter = 0
+    prefix_counter = suffic_counter_start
     unique_named_funcs_obtained_from_funcs = []
     for func_name_pair in named_funcs_obtained_from_funcs:
         name, func = func_name_pair
@@ -356,7 +360,11 @@ class Line:
 
         # It might make sense that if no funcs are specified, we take the lined to be
         # the identity, but we'll implement only when needed
+        # TODO: Refactor validation as hidden func (underscore-prefixed)
+        # TODO: Move validation just before attr assignment (after normalize)
         assert len(funcs) > 0, "You need to specify at least one function!"
+        assert all(list(map(callable, funcs))), "Hey, some funcs not callable!"
+
         funcs, named_funcs = _normalize_funcs_and_named_funcs(funcs, named_funcs)
 
         self.funcs = funcs
@@ -524,7 +532,8 @@ class Line:
                 f"See https://pypi.org/project/graphviz/."
             )
 
-        body = list(self.dot_digraph_body(*args, **kwargs))
+        # Note: Since graphviz 0.18, need to have a newline in body lines!
+        body = list(map(_add_new_line_if_none, self.dot_digraph_body(*args, **kwargs)))
         return graphviz.Digraph(body=body)
 
     def __repr__(self):
@@ -1128,6 +1137,15 @@ class Digraph:
         return stack
 
 
+def _add_new_line_if_none(s: str):
+    """Since graphviz 0.18, need to have a newline in body lines.
+    This util is there to address that, adding newlines to body lines
+    when missing."""
+    if s and s[-1] != "\n":
+        return s + "\n"
+    return s
+
+
 if __name__ == "__main__":
     from lined.base import _merge_funcs_and_named_funcs
     import pytest
